%global srcname pydata-sphinx-theme

Name:           python-%{srcname}
Version:        0.7.1
Release:        1%{?dist}
Summary:        Bootstrap-based Sphinx theme from the PyData community

# This project is BSD.
# The bundled bootstrap and kickass JavaScript libraries are MIT.
License:        BSD and MIT
URL:            https://github.com/pydata/pydata-sphinx-theme
Source0:        %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz
# Fedora-only patch: unbundle the fontawesome fonts
Patch0:         %{name}-fontawesome.patch

BuildArch:      noarch

BuildRequires:  fontawesome5-fonts-all
BuildRequires:  make
BuildRequires:  python3-devel
BuildRequires:  %{py3_dist beautifulsoup4}
BuildRequires:  %{py3_dist jupyter-sphinx}
BuildRequires:  %{py3_dist numpy}
BuildRequires:  %{py3_dist numpydoc}
BuildRequires:  %{py3_dist pandas}
BuildRequires:  %{py3_dist pip}
BuildRequires:  %{py3_dist plotly}
BuildRequires:  %{py3_dist pytest}
BuildRequires:  %{py3_dist pytest-regressions}
BuildRequires:  %{py3_dist recommonmark}
BuildRequires:  %{py3_dist setuptools}
BuildRequires:  %{py3_dist sphinx}
BuildRequires:  %{py3_dist sphinx-sitemap}
BuildRequires:  %{py3_dist wheel}
BuildRequires:  %{py3_dist xarray}

%global _description %{expand:
This package contains a Sphinx extension for creating document components
optimized for HTML+CSS.

- The panels directive creates panels of content in a grid layout,
  utilizing both the Bootstrap 4 grid system, and cards layout.

- The link-button directive creates a clickable button, linking to a URL
  or reference, and can also be used to make an entire panel clickable.

- The dropdown directive creates content that can be toggled.

- The tabbed directive creates tabbed content.

- opticon and fa (fontawesome) roles allow for inline icons to be added.}

%description %_description

%package     -n python3-%{srcname}
Summary:        Sphinx extension for creating panels in a grid layout
Requires:       fontawesome5-fonts-all

# The generated JavaScript contains two external libraries
Provides:       bundled(nodejs-bootstrap) = 4.5.0
Provides:       bundled(nodejs-kickass) = 1.16.1

%description -n python3-%{srcname} %_description

%package        doc
Summary:        Documentation for %{srcname}

%description    doc
Documentation for %{srcname}.

%prep
%autosetup -n %{srcname}-%{version} -p1

# Make sure we don't use the bundled copy of fontawesome
rm -fr pydata_sphinx_theme/static/vendor

%build
%pyproject_wheel

# Build the documentation
PYTHONPATH=$(ls -1d $PWD/.pyproject-builddir/pip-req-build-*) make -C docs html
rm docs/_build/html/.buildinfo

%install
%pyproject_install

%check
%pytest

%files -n python3-%{srcname}
%doc README.md
%license LICENSE
%{python3_sitelib}/pydata_sphinx_theme*

%files doc
%doc docs/_build/html docs/_build/jupyter_execute
%license LICENSE

%changelog
* Sat Oct  2 2021 Jerry James <loganjerry@gmail.com> - 0.7.1-1
- Version 0.7.1
- Drop upstreamed -sphinx4.1 and -docutils patches

* Wed Sep 22 2021 Jerry James <loganjerry@gmail.com> - 0.6.3-2
- Add upstream -docutils patch to fix FTI (bz 2006934)

* Tue Jul 13 2021 Jerry James <loganjerry@gmail.com> - 0.6.3-1
- Initial RPM
